========
Research
========

The CAPPr method is fleshed it out in my `question on Cross Validated
<https://stats.stackexchange.com/q/601159/337906>`_.

.. toctree::
   :maxdepth: 2

   related_work
   computational_performance
   future_research
